@@ -1,6 +1,4 @@
-// Copyright (c) 2001-2005 Peter Karlsson
-//
-// $Id: convert.cpp,v 1.19 2005/07/14 13:28:24 peterk Exp $
+// Copyright (c) 2001-2007 Peter Karlsson
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -231,7 +229,7 @@ Decoder *Decoder::GetDecoderByName(const char *charset)
 Decoder *Decoder::GetDecoderByKludges(const char *kludges)
 {
     // Find CHRS kludge
-    char *chrs = kludges ? strstr(kludges, "\x01""CHRS: ") : NULL;
+    const char *chrs = kludges ? strstr(kludges, "\x01""CHRS: ") : NULL;
     if (!chrs)
     {
         // Return first in Fido table
@@ -254,7 +252,7 @@ Decoder *Decoder::GetDecoderByKludges(const char *kludges)
     // Test for special case: IBMPC may have CODEPAGE specifier (FDAPX/w)
     if (0 == fcompare(charset, "IBMPC"))
     {
-        char *codepage = kludges ? strstr(kludges, "\x01""CODEPAGE: ") : NULL;
+        const char *codepage = kludges ? strstr(kludges, "\x01""CODEPAGE: ") : NULL;
         if (codepage)
         {
             // Isolate codepage number
@@ -296,9 +294,7 @@ Decoder *Decoder::GetDecoderByKludges(const char *kludges)
 Decoder *Decoder::GetDecoderByMIMEHeaders(const char *headers)
 {
     // Find charset identifier
-#if defined(HAVE_STRCASESTR)
-    char *charset = headers ? strcasestr(headers, "charset=") : NULL;
-#elif defined(HAVE_STRISTR)
+#if defined(HAVE_STRISTR)
     char *charset = headers ? stristr(headers, "charset=") : NULL;
 #else
     const char *charset = NULL;
@@ -347,18 +343,18 @@ Decoder *Decoder::GetDecoderByMIMEHeaders(const char *headers)
     const char *p;
     if (NULL != (p = strchr(start, ' ')))
     {
-    	if (p < next)
-    		next = p;
+        if (p < next)
+            next = p;
     }
     if (NULL != (p = strchr(start, 1)))
     {
-    	if (p < next)
-    		next = p;
+        if (p < next)
+            next = p;
     }
     if (NULL != (p = strchr(start, ',')))
     {
-    	if (p < next)
-    		next = p;
+        if (p < next)
+            next = p;
     }
 
     string charsetstring(start, next - start);
@@ -435,6 +431,10 @@ wstring UTF8Decoder::Decode(const string &input)
             // U+0080 - U+07FF
             ucs  = (*(i ++) & 0x1F) <<  6;
             ucs |=  *i      & 0x3F;
+            if (ucs < 0x80)
+            {
+                ucs = '?';
+            }
         }
         else if (0xE0 == (*i & 0xF0))
         {
@@ -442,6 +442,10 @@ wstring UTF8Decoder::Decode(const string &input)
             ucs  = (*(i ++) & 0x0F) << 12;
             ucs |= (*(i ++) & 0x3F) <<  6;
             ucs |=  *i      & 0x3F;
+            if (ucs < 0x800 || (ucs >= 0xD800 && ucs <= 0xDFFF))
+            {
+                ucs = '?';
+            }
         }
         else if (0xF0 == (*i & 0xF8))
         {
@@ -450,6 +454,10 @@ wstring UTF8Decoder::Decode(const string &input)
             ucs |= (*(i ++) & 0x3F) << 12;
             ucs |= (*(i ++) & 0x3F) <<  6;
             ucs |=  *i      & 0x3F;
+            if (ucs < 0x10000)
+            {
+                ucs = '?';
+            }
         }
         else if (0xF8 == (*i & 0xFC))
         {
@@ -459,6 +467,10 @@ wstring UTF8Decoder::Decode(const string &input)
             ucs |= (*(i ++) & 0x3F) << 12;
             ucs |= (*(i ++) & 0x3F) <<  6;
             ucs |=  *i      & 0x3F;
+            if (ucs < 0x200000)
+            {
+                ucs = '?';
+            }
         }
         else if (0xFC == (*i & 0xFE))
         {
@@ -469,6 +481,10 @@ wstring UTF8Decoder::Decode(const string &input)
             ucs |= (*(i ++) & 0x3F) << 12;
             ucs |= (*(i ++) & 0x3F) <<  6;
             ucs |=  *i      & 0x3F;
+            if (ucs < 0x4000000)
+            {
+                ucs = '?';
+            }
         }
 
 #ifdef HAVE_WORKING_WSTRING
@@ -565,7 +581,7 @@ string SBCSEncoder::Encode(const wstring &input)
             // ASCII always map to ASCII, even for 7-bit character sets
             // (this means that a backslash in input will look wrong in
             // output for iso-ir-11, but we can live with that)
-            s += char(ucs);
+            s += static_cast<char>(ucs);
         }
         else
         {
@@ -579,7 +595,7 @@ string SBCSEncoder::Encode(const wstring &input)
                 mid = low + (high - low) / 2;
                 if (ucs == outmap[mid].unicode)
                 {
-                    result = outmap[mid].legacy;
+                    result = static_cast<char>(outmap[mid].legacy);
                 }
                 else if (ucs < outmap[mid].unicode)
                 {
