@@ -1,6 +1,4 @@
-// Copyright (c) 2001-2005 Peter Karlsson
-//
-// $Id: nntpread.cpp,v 1.18 2005/07/11 12:38:02 peterk Exp $
+// Copyright (c) 2001-2007 Peter Karlsson
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,9 +14,12 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include <config.h>
+#include <stdlib.h>
 #include <time.h>
 #include <string.h>
-#include <unistd.h>
+#if defined(HAVE_UNISTD_H)
+# include <unistd.h>
+#endif
 #include <sys/types.h>
 #if defined(HAVE_NETDB_H)
 # include <netdb.h>
@@ -27,11 +28,13 @@
 # include <sys/socket.h>
 #elif defined(HAVE_WINSOCK_H)
 # include <winsock.h>
+#elif defined(HAVE_WINSOCK2_H)
+# include <winsock2.h>
 #endif
 #if defined(HAVE_NETINET_IN_H)
 # include <netinet/in.h>
 #endif
-#if !defined(HAVE_WORKING_SOCKET_FDOPEN) && !defined(HAVE_WINSOCK_H)
+#if !defined(HAVE_WORKING_SOCKET_FDOPEN) && !defined(HAVE_WINSOCK_H) && !defined(HAVE_WINSOCK2_H)
 # if defined(HAVE_ERRNO_H)
 #  include <errno.h>
 # elif defined(HAVE_SYS_ERRNO_H)
@@ -45,6 +48,7 @@
 # define sleep(x) _sleep(x)
 #endif
 #include <ctype.h>
+#include <assert.h>
 
 #include "nntpread.h"
 #include "statengine.h"
@@ -89,7 +93,7 @@ NntpRead::~NntpRead()
         fclose(sock);
 #endif
         shutdown(sockfd, 2);
-#if defined(HAVE_WINSOCK_H)
+#if defined(HAVE_WINSOCK_H) || defined(HAVE_WINSOCK2_H)
         closesocket(sockfd);
 #else
         close(sockfd);
@@ -97,7 +101,7 @@ NntpRead::~NntpRead()
     }
     delete[] articles;
 
-#if defined(HAVE_WINSOCK_H)
+#if defined(HAVE_WINSOCK_H) || defined(HAVE_WINSOCK2_H)
     WSACleanup();
 #endif
 }
@@ -120,7 +124,7 @@ bool NntpRead::Transfer(time_t starttime, time_t endtime,
     // We are unable to retrieve information on arrival times
     destination.NoArrivalTime();
 
-#if defined(HAVE_WINSOCK_H)
+#if defined(HAVE_WINSOCK_H) || defined(HAVE_WINSOCK2_H)
     WORD versionrequest = MAKEWORD(1, 1);
     WSADATA wsadata;
     int err = WSAStartup(versionrequest, &wsadata);
@@ -477,13 +481,13 @@ bool NntpRead::SendLine(const char *line)
     // Iterate until entire line is sent
     while (linelength)
     {
-        int rc = send(sockfd, line, linelength, 0);
+        int rc = send(sockfd, line, static_cast<int>(linelength), 0);
 
         // Check for possible errors
         if (-1 == rc)
         {
             // Ignore "interrupted", "try again" and "would block" errors.
-# if defined(HAVE_WINSOCK_H)
+# if defined(HAVE_WINSOCK_H) || defined(HAVE_WINSOCK2_H)
             int wsa_errno = WSAGetLastError();
             if (WSAEINTR != wsa_errno &&
 #  if defined(WSAEAGAIN)
@@ -503,7 +507,7 @@ bool NntpRead::SendLine(const char *line)
         }
         else
         {
-            assert(rc <= linelength);
+            assert(rc <= static_cast<int>(linelength));
 
             // Remove the handled sent part of the buffer
             linelength -= rc;
@@ -517,7 +521,13 @@ bool NntpRead::SendLine(const char *line)
             }
 
             // Pause a second before trying again
-            sleep(1);
+#if defined(HAVE_SLEEP)
+			sleep(1);
+#elif defined(HAVE_U_SLEEP)
+			_sleep(1);
+#else
+# error "Port me"
+#endif
         }
     }
     return true;
@@ -550,7 +560,15 @@ bool NntpRead::GetLine(char *outbuffer, size_t maxlen)
             if (maxlen)
             {
                 copiedanything = true;
+#ifdef __GNUC__
                 size_t copylen = bytes <? maxlen;
+#else
+                size_t copylen = bytes;
+				if (maxlen < copylen)
+				{
+					copylen = maxlen;
+				}
+#endif
                 memcpy(outbuffer, socketbuffer, copylen);
                 outbuffer += copylen;
                 maxlen -= copylen;
@@ -571,7 +589,7 @@ bool NntpRead::GetLine(char *outbuffer, size_t maxlen)
             if (-1 == rc)
             {
                 // Ignore "interrupted" and "try again" errors.
-# if defined(HAVE_WINSOCK_H)
+# if defined(HAVE_WINSOCK_H) || defined(HAVE_WINSOCK2_H)
                 int wsa_errno = WSAGetLastError();
                 if (WSAEINTR != wsa_errno
 #  if defined(WSAEAGAIN)
