@@ -1,6 +1,4 @@
-// Copyright (c) 1999-2001 Peter Karlsson
-//
-// $Id: squishread.h,v 1.12 2001/07/04 21:50:32 peterk Exp $
+// Copyright (c) 1999-2007 Peter Karlsson
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,7 +23,7 @@
 #include "utility.h"
 
 #if defined(__GNUC__) || defined(__EMX__)
-# pragma pack(1)
+# pragma pack(push, 1)
 #endif
 
 class StatEngine;
@@ -131,7 +129,7 @@ protected:
 };
 
 #if defined(__GNUC__) || defined(__EMX__)
-# pragma pack()
+# pragma pack(pop)
 #endif
 
 #endif
