@@ -1,11 +1,9 @@
 // Turquoise SuperStat
 //
 // A statistic collection program for Fidonet and Usenet systems
-// Version 2.2
+// Version 3.0
 //
-// Copyright (c) 1998-2005 Peter Karlsson
-//
-// $Id: turqstat.cpp,v 1.54 2005/07/14 13:28:24 peterk Exp $
+// Copyright (c) 1998-2008 Peter Karlsson
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,6 +37,12 @@
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
+#ifdef HAVE_WINSOCK2_H
+# include <winsock2.h>
+#endif
+#ifdef HAVE_WIN32_GETMODULEFILENAME
+# include <windows.h>
+#endif
 
 #include "statengine.h"
 #include "statview.h"
@@ -57,6 +61,7 @@
 #include "utility.h"
 #include "mytime.h"
 #include "output.h"
+#include "template.h"
 
 /**
  * Wrapper class to retrieve data. This class is called from the main
@@ -122,6 +127,7 @@ int main(int argc, char *argv[])
     unsigned days = 0;
     unsigned maxnum = 15;
     char *basepath = NULL;
+	const char *templatefile = NULL;
     StatRetr::basetype_e basetype = StatRetr::squish;
     bool quoters = true, topwritten = true, topreceived = true,
          topsubjects = true, topprograms = true, weekstats = true,
@@ -136,6 +142,9 @@ int main(int argc, char *argv[])
 #if defined(HAVE_LOCALE_H) || defined(HAVE_OS2_COUNTRYINFO) || defined(HAVE_WIN32_LOCALEINFO)
     bool uselocale = false;
 #endif
+#if defined(HAVE_WIN32_GETMODULEFILENAME)
+	char defaulttemplate[_MAX_PATH];
+#endif
 
     // Setup locale
 #ifdef HAVE_LOCALE_H
@@ -153,9 +162,9 @@ int main(int argc, char *argv[])
     // Handle arguments
     int c;
 #if defined(HAVE_LOCALE_H) || defined(HAVE_OS2_COUNTRYINFO) || defined(HAVE_WIN32_LOCALEINFO)
-    while (EOF != (c = getopt(argc, argv, "d:n:a:r:C:smofjptuQWRSPOHDVNTALU?")))
+    while (EOF != (c = getopt(argc, argv, "d:n:a:r:C:F:smofjptuQWRSPOHDVNTALU?")))
 #else
-    while (EOF != (c = getopt(argc, argv, "d:n:a:r:C:smofjptuQWRSPOHDVNTAU?")))
+    while (EOF != (c = getopt(argc, argv, "d:n:a:r:C:F:smofjptuQWRSPOHDVNTAU?")))
 #endif
     {
         switch (c)
@@ -165,6 +174,7 @@ int main(int argc, char *argv[])
             case 'a':   basepath = optarg;                          break;
             case 'r':   evaluaterange(optarg, &range_start_p, &range_end_p);
                                                                     break;
+            case 'F':   templatefile = optarg;                      break;
 
             case 's':   basetype = StatRetr::squish;                break;
             case 'm':   basetype = StatRetr::sdm;                   break;
@@ -221,12 +231,49 @@ int main(int argc, char *argv[])
         return 1;
     }
 
+    // Load template
+    if (!templatefile)
+    {
+        // Use default template if none was supplied.
+#if defined(HAVE_WIN32_GETMODULEFILENAME)
+		// Windows: Template is in the same directory as the EXE file.
+		GetModuleFileNameA(NULL, defaulttemplate, _MAX_PATH);
+		char *p = strrchr(defaulttemplate, '\\');
+		if (p && p < defaulttemplate + _MAX_PATH - 13)
+		{
+			strcpy(p + 1, "default.tpl");
+			templatefile = defaulttemplate;
+		}
+#else
+		// Unix-like environment: Template is in a pre-defined installation
+		// directory.
+        templatefile = DATA
+#ifdef BACKSLASH_PATHS
+            "\\"
+#else
+            "/"
+#endif
+            "default.tpl";
+#endif
+    }
+
+    bool is_error = false;
+    Template *output_template_p = Template::Parse(templatefile, is_error);
+    if (!output_template_p || is_error)
+    {
+		TDisplay *display = TDisplay::GetOutputObject();
+		display->ErrorQuit(TDisplay::template_parse_error, 2);
+    }
+
     // Create engine object
     StatEngine engine;
 
     // Create view object
     StatView view;
 
+    // Select output format
+    view.SetTemplate(output_template_p);
+
     // Enable toplists we want
     view.EnableQuoters(quoters);
     view.EnableTopWritten(topwritten);
@@ -270,6 +317,7 @@ int main(int argc, char *argv[])
 
     delete range_start_p;
     delete range_end_p;
+    delete output_template_p;
 
     return 0;
 }
@@ -362,11 +410,12 @@ void helpscreen(void)
 {
     cout << "Usage: turqstat [options] outputfile areadef(s)" << endl;
     cout << endl;
-    cout << "Data selection options:" << endl;
+    cout << "Data selection and display options:" << endl;
     cout << "  -a path  Base path (see below)    -d days   Days back to count"
          << endl;
     cout << "  -n num   Maximum entries          -r range  Date range"
          << endl;
+    cout << "  -F file  Use template file (default: default.tpl)" << endl;
     cout << endl;
     cout << "Input selection options:" << endl;
     cout << "  -s  Squish       -j  JAM          -p  MyPoint*" << endl;
@@ -421,7 +470,7 @@ void evaluaterange(const char *rangespec,
         if (time_t(-1) != **range_start_pp)
         {
             const char *rangespec2 = separator + 1;
-            int charsleft = strlen(rangespec2);
+            size_t charsleft = strlen(rangespec2);
             if (0 == charsleft)
             {
                 **range_end_pp = time_t(DISTANT_FUTURE);
