@@ -1,6 +1,4 @@
-// Copyright (c) 1998-2005 Peter Karlsson
-//
-// $Id: utility.h,v 1.25 2005/07/11 12:38:09 peterk Exp $
+// Copyright (c) 1998-2008 Peter Karlsson
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -28,7 +26,7 @@ using namespace std;
 #endif
 
 #if defined(__GNUC__) || defined(__EMX__)
-# pragma pack(1)
+# pragma pack(push, 1)
 #endif
 
 /** MS-DOS style time stamp. */
@@ -50,7 +48,7 @@ struct stamp_s
 };
 
 #if defined(__GNUC__) || defined(__EMX__)
-# pragma pack()
+# pragma pack(pop)
 #endif
 
 /** Highest possible time_t value */
@@ -58,7 +56,11 @@ struct stamp_s
 # define CHAR_BIT 8
 #endif
 
-#define DISTANT_FUTURE ((1UL << (CHAR_BIT * SIZEOF_TIME_T - 1)) - 1)
+#if SIZEOF_TIME_T > 4
+# define DISTANT_FUTURE ((1ULL << (CHAR_BIT * SIZEOF_TIME_T - 1)) - 1)
+#else
+# define DISTANT_FUTURE ((1UL << (CHAR_BIT * SIZEOF_TIME_T - 1)) - 1)
+#endif
 
 /**
  * Compare two strings case in-sensitively.
